# Language Server Client

The Biscuit Language Server Client (LSP) is a JSON-RPC based client that allows to communicate with language servers to perform operations like code completion, go to definition, find references, hover, outline, etc.

## Features

The Biscuit Language Server Client provides the following features:

- **Code Completion**: Provides code completion suggestions.
- **Hover**: Shows information about symbols.
- **Go to Definition**: Jumps to the definition of a symbol.
- **Find References**: Finds references to a symbol.
- **Document Outline**: Shows a list of symbols in the document.
- **Document Symbols Palette**: Shows a list of symbols in the document.
- **Document Rename**: Renames a symbol in the document.
